@@ -1,9 +1,8 @@
-from sys import exit, argv
-
-import toml
+from sys import exit
 
 import py2dmat
 import py2dmat.mpi
+import py2dmat.util.toml
 
 
 def main():
@@ -23,7 +22,7 @@ def main():
     file_name = args.inputfile
     inp = {}
     if py2dmat.mpi.rank() == 0:
-        inp = toml.load(file_name)
+        inp = py2dmat.util.toml.load(file_name)
     if py2dmat.mpi.size() > 1:
         inp = py2dmat.mpi.comm().bcast(inp, root=0)
     info = py2dmat.Info(inp)
@@ -35,6 +34,8 @@ def main():
         from .algorithm.min_search import Algorithm
     elif algname == "exchange":
         from .algorithm.exchange import Algorithm
+    elif algname == "pamc":
+        from .algorithm.pamc import Algorithm
     elif algname == "bayes":
         from .algorithm.bayes import Algorithm
     else:
@@ -51,6 +52,10 @@ def main():
         from .solver.sim_trhepd_rheed import Solver
     elif solvername == "sim-trhepd-rheed":
         from .solver.sim_trhepd_rheed import Solver
+    elif solvername == "sxrd":
+        from .solver.sxrd import Solver
+    elif solvername == "leed":
+        from .solver.leed import Solver
     elif solvername == "analytical":
         from .solver.analytical import Solver
     else:
