@@ -1,12 +1,14 @@
 # -*- coding: utf-8 -*-
 from abc import ABCMeta, abstractmethod
 
+import subprocess
+
 import py2dmat
 import py2dmat.mpi
 
 # type hints
 from pathlib import Path
-from typing import Dict
+from typing import Dict, List
 
 
 class SolverBase(object, metaclass=ABCMeta):
@@ -15,6 +17,7 @@ class SolverBase(object, metaclass=ABCMeta):
     proc_dir: Path
     work_dir: Path
     _name: str
+    dimension: int
     timer: Dict[str, Dict]
 
     @abstractmethod
@@ -25,31 +28,32 @@ class SolverBase(object, metaclass=ABCMeta):
         self.work_dir = self.proc_dir
         self._name = ""
         self.timer = {"prepare": {}, "run": {}, "post": {}}
-
-    @abstractmethod
-    def default_run_scheme(self) -> str:
-        """
-        Return
-        -------
-        str
-            run_scheme.
-        """
-        pass
+        if "dimension" in info.solver:
+            self.dimension = info.solver["dimension"]
+        else:
+            self.dimension = info.base["dimension"]
 
     @property
     def name(self) -> str:
         return self._name
 
-    def command(self):
-        raise NotImplementedError()
-
-    def function(self):
+    @abstractmethod
+    def prepare(self, message: py2dmat.Message) -> None:
         raise NotImplementedError()
 
     @abstractmethod
-    def prepare(self, message: py2dmat.Message) -> None:
-        pass
+    def run(self, nprocs: int = 1, nthreads: int = 1) -> None:
+        raise NotImplementedError()
 
     @abstractmethod
     def get_results(self) -> float:
-        pass
+        raise NotImplementedError()
+
+    def _run_by_subprocess(self, command: List[str]) -> None:
+        with open("stdout", "w") as fi:
+            subprocess.run(
+                command,
+                stdout=fi,
+                stderr=subprocess.STDOUT,
+                check=True,
+            )
